//
//  VNKVenue.m
//  VenueKit
//
//  Created by Logan Collins on 3/13/13.
//  Copyright (c) 2013 Sunflower Softworks. All rights reserved.
//

#import "VNKVenue.h"
#import "VNKVenue_Private.h"

#import "VNKVenueCategory_Private.h"


NSString * VNKAddressStreetKey = @"address";
NSString * VNKAddressCrossStreetKey = @"crossStreet";
NSString * VNKAddressCityKey = @"city";
NSString * VNKAddressStateKey = @"state";
NSString * VNKAddressPostalCodeKey = @"postalCode";
NSString * VNKAddressCountryKey = @"country";


@implementation VNKVenue

- (id)initWithDictionary:(NSDictionary *)dictionary service:(VNKService *)service {
	self = [super init];
	if (self) {
        self.service = service;
        
		self.identifier = dictionary[@"id"];
		self.name = dictionary[@"name"];
		
		NSDictionary *locationDict = dictionary[@"location"];
		if (locationDict[@"lat"] != nil && locationDict[@"lng"] != nil) {
			CLLocationDegrees latitude = [locationDict[@"lat"] doubleValue];
			CLLocationDegrees longitude = [locationDict[@"lng"] doubleValue];
			CLLocation *location = [[CLLocation alloc] initWithLatitude:latitude longitude:longitude];
			self.location = location;
		}
		
		self.url = dictionary[@"url"];
		self.verified = [dictionary[@"verified"] boolValue];
		self.addressDictionary = dictionary[@"location"];
		
		if (dictionary[@"createdAt"] != nil) {
			NSTimeInterval timeInterval = [dictionary[@"createdAt"] doubleValue];
			self.creationDate = [NSDate dateWithTimeIntervalSince1970:timeInterval];
		}
		
		self.tags = dictionary[@"tags"];
		
		NSArray *categoryDicts = dictionary[@"categories"];
		NSMutableArray *categories = [NSMutableArray arrayWithCapacity:[categoryDicts count]];
		for (NSDictionary *categoryDict in categoryDicts) {
			VNKVenueCategory *category = [[VNKVenueCategory alloc] initWithDictionary:categoryDict service:service];
			[categories addObject:category];
		}
		self.categories = categories;
	}
	return self;
}

- (id)init {
	@throw [NSException exceptionWithName:NSInvalidArgumentException reason:[NSString stringWithFormat:@"%@ should not be directly initialized.", [self class]] userInfo:nil];
}

@end
